==> jc-1.4.0.tar.gz: javax/crypto/ShortBufferException.h <==
// public class javax.crypto.ShortBufferException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class d79a62a9328ccea1 javax_crypto_ShortBufferException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_javax_crypto_ShortBufferException_H_
#define _JC_javax_crypto_ShortBufferException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_ShortBufferException$sub_refs	_jc_javax_crypto_ShortBufferException$sub_refs;
typedef struct _jc_javax_crypto_ShortBufferException$sub_nonrefs	_jc_javax_crypto_ShortBufferException$sub_nonrefs;
typedef struct _jc_javax_crypto_ShortBufferException$refs	_jc_javax_crypto_ShortBufferException$refs;
typedef struct _jc_javax_crypto_ShortBufferException$nonrefs	_jc_javax_crypto_ShortBufferException$nonrefs;
typedef struct _jc_javax_crypto_ShortBufferException$object	_jc_javax_crypto_ShortBufferException$object;

typedef struct _jc_javax_crypto_ShortBufferException$fields_struct	_jc_javax_crypto_ShortBufferException$fields_struct;
typedef const struct _jc_javax_crypto_ShortBufferException$vmethods	_jc_javax_crypto_ShortBufferException$vmethods;
typedef const struct _jc_javax_crypto_ShortBufferException$vtable	_jc_javax_crypto_ShortBufferException$vtable;
typedef const struct _jc_javax_crypto_ShortBufferException$vtype	_jc_javax_crypto_ShortBufferException$vtype;

// Class fields structure
struct _jc_javax_crypto_ShortBufferException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_ShortBufferException$fields_struct _jc_javax_crypto_ShortBufferException$class_fields;

// Constructors
extern void _jc_javax_crypto_ShortBufferException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_ShortBufferException$object *);
extern void _jc_javax_crypto_ShortBufferException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_crypto_ShortBufferException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_crypto_ShortBufferException$vmethods {
};

// Vtable
struct _jc_javax_crypto_ShortBufferException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_crypto_ShortBufferException$vmethods	javax_crypto_ShortBufferException;
};

// Vtype
struct _jc_javax_crypto_ShortBufferException$vtype {
	_jc_type			type;
	_jc_javax_crypto_ShortBufferException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_ShortBufferException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_ShortBufferException$refs {
    _jc_javax_crypto_ShortBufferException$sub_refs	javax_crypto_ShortBufferException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_ShortBufferException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_ShortBufferException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_crypto_ShortBufferException$sub_nonrefs	javax_crypto_ShortBufferException;
};

// Object instance structure
struct _jc_javax_crypto_ShortBufferException$object {
	_jc_javax_crypto_ShortBufferException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_ShortBufferException$vtype	*vtype;
	_jc_javax_crypto_ShortBufferException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_ShortBufferException$vtype _jc_javax_crypto_ShortBufferException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_ShortBufferException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_ShortBufferException$class_object;

#endif	/* _JC_javax_crypto_ShortBufferException_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/ShortBufferException.h <==
// public class javax.crypto.ShortBufferException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class d79a62a9328ccea1 javax_crypto_ShortBufferException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_javax_crypto_ShortBufferException_H_
#define _JC_javax_crypto_ShortBufferException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_ShortBufferException$sub_refs	_jc_javax_crypto_ShortBufferException$sub_refs;
typedef struct _jc_javax_crypto_ShortBufferException$sub_nonrefs	_jc_javax_crypto_ShortBufferException$sub_nonrefs;
typedef struct _jc_javax_crypto_ShortBufferException$refs	_jc_javax_crypto_ShortBufferException$refs;
typedef struct _jc_javax_crypto_ShortBufferException$nonrefs	_jc_javax_crypto_ShortBufferException$nonrefs;
typedef struct _jc_javax_crypto_ShortBufferException$object	_jc_javax_crypto_ShortBufferException$object;

typedef struct _jc_javax_crypto_ShortBufferException$fields_struct	_jc_javax_crypto_ShortBufferException$fields_struct;
typedef const struct _jc_javax_crypto_ShortBufferException$vmethods	_jc_javax_crypto_ShortBufferException$vmethods;
typedef const struct _jc_javax_crypto_ShortBufferException$vtable	_jc_javax_crypto_ShortBufferException$vtable;
typedef const struct _jc_javax_crypto_ShortBufferException$vtype	_jc_javax_crypto_ShortBufferException$vtype;

// Class fields structure
struct _jc_javax_crypto_ShortBufferException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_ShortBufferException$fields_struct _jc_javax_crypto_ShortBufferException$class_fields;

// Constructors
extern void _jc_javax_crypto_ShortBufferException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_ShortBufferException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_ShortBufferException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_crypto_ShortBufferException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_crypto_ShortBufferException$vmethods {
};

// Vtable
struct _jc_javax_crypto_ShortBufferException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_crypto_ShortBufferException$vmethods	javax_crypto_ShortBufferException;
};

// Vtype
struct _jc_javax_crypto_ShortBufferException$vtype {
	_jc_type			type;
	_jc_javax_crypto_ShortBufferException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_ShortBufferException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_ShortBufferException$refs {
    _jc_javax_crypto_ShortBufferException$sub_refs	javax_crypto_ShortBufferException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_ShortBufferException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_ShortBufferException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_crypto_ShortBufferException$sub_nonrefs	javax_crypto_ShortBufferException;
};

// Object instance structure
struct _jc_javax_crypto_ShortBufferException$object {
	_jc_javax_crypto_ShortBufferException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_ShortBufferException$vtype	*vtype;
	_jc_javax_crypto_ShortBufferException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_ShortBufferException$vtype _jc_javax_crypto_ShortBufferException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_ShortBufferException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_ShortBufferException$class_object;

#endif	/* _JC_javax_crypto_ShortBufferException_H_ */
